
export class FormatUtils {

   static formatTimeSpan(from, to, includeSeconds) {
    const secondsTimeDifference = Math.floor((to.getTime() - from.getTime()) / 1000);

    if (secondsTimeDifference <= 0) {
      return "0 Sekunden";
    } else {
      let remainingTimeString = "";

      let timeDelta = secondsTimeDifference;

      const daysDifference = Math.floor(timeDelta / 86400);
      timeDelta -= daysDifference * 86400;
      const hoursDifference = Math.floor(timeDelta / 3600);
      timeDelta -= hoursDifference * 3600;
      const minutesDifference = Math.floor(timeDelta / 60);
      timeDelta -= minutesDifference * 60;
      const secondsDifference = Math.floor(timeDelta % 60);

      if (daysDifference > 0) {
        remainingTimeString += `${daysDifference} ${daysDifference > 1 ? "Tage" : "Tag"}`;
      }
      if (hoursDifference > 0) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ", ";
        }
        remainingTimeString += `${hoursDifference} ${hoursDifference > 1 ? "Stunden" : "Stunde"}`;
      }
      if (minutesDifference > 0 && daysDifference < 1) {
        if (remainingTimeString.length > 0) {
          remainingTimeString += ", ";
        }
        remainingTimeString += `${minutesDifference} ${minutesDifference > 1 ? "Minuten" : "Minute"}`;
      }

      if (includeSeconds) {
        if (daysDifference < 1 && hoursDifference < 1) {
          if (remainingTimeString.length > 0) {
            remainingTimeString += ", ";
          }
          remainingTimeString += `${secondsDifference} ${secondsDifference > 1 ? "Sekunden" : "Sekunde"}`;
        }
      } else {
        if (remainingTimeString.length === 0) {
          remainingTimeString += "< 1 Minute";
        }
      }

      return `${remainingTimeString}`.trim();
    }
  }

  static formatVehicleFuelType(fuelType) {
    switch (fuelType) {
      case 'GASOLINE':
        return 'Benzin';
      case 'DIESEL':
        return 'Diesel';
      case 'HYBRID':
        return 'Hybrid';
      case 'ELECTRIC':
        return 'Elektrisch';
      case 'AUTOGAS':
        return 'Autogas';
      case 'OTHER':
      default:
        return 'Andere';
    }
  }

  static formatVehicleCategory(category) {
    switch (category) {
      case 'COMPACT':
        return 'Kleinwagen';
      case 'STATION':
        return 'Kombi';
      case 'SEDAN':
        return 'Limousine';
      case 'ROADSTER_CONVERTIBLE':
        return 'Roadster/Cabrio';
      case 'SUV':
        return 'Geländewagen';
      case 'COUPE':
        return 'Coupé';
      case 'VAN':
        return "Van";
      case 'MULTIVAN':
        return 'Kastenwagen';
      case 'PICK_UP':
        return 'Pritschenwagen/Pick-Up';
      default:
        return 'Andere';
    }
  }

  static formatThumbnailUrl(url, width, height) {
    return url.replace("upload/", `upload/c_limit,h_${height},w_${width},fl_lossy,f_auto,q_auto/`);
  }
}
